Learn R Programming

lncDIFF (version 1.0.0)

hnsc.edata: lncRNA Fragments Per Killobase per Million (FPKM) in a head and neck squamous cell carcinomas (hnsc) study.

Description

lncRNA Fragments Per Killobase per Million (FPKM) in a head and neck squamous cell carcinomas (hnsc) study.

Usage

hnsc.edata

Arguments

Format

A data frame of lncRNA FPKM with 1000 rows (i.e. genes) and 80 columns (i.e. samples ).